from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import well_known_types as _well_known_types
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Any(_message.Message, _well_known_types.Any):
    __slots__ = ["type_url", "value"]
    TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    type_url: str
    value: bytes
    def __init__(self, type_url: _Optional[str] = ..., value: _Optional[bytes] = ...) -> None: ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n"cosmos/authz/v1beta1/genesis.proto\x12\x14cosmos.authz.v1beta1\x1a\x14gogoproto/gogo.proto\x1a cosmos/authz/v1beta1/authz.proto"U\n\x0cGenesisState\x12E\n\rauthorization\x18\x01 \x03(\x0b2(.cosmos.authz.v1beta1.GrantAuthorizationB\x04\xc8\xde\x1f\x00B&Z$github.com/cosmos/cosmos-sdk/x/authzb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz'
    _GENESISSTATE.fields_by_name['authorization']._options = None
    _GENESISSTATE.fields_by_name['authorization']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE._serialized_start = 116
    _GENESISSTATE._serialized_end = 201




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....ibc.applications.transfer.v1 import transfer_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ibc/applications/transfer/v1/genesis.proto\x12\x1cibc.applications.transfer.v1\x1a+ibc/applications/transfer/v1/transfer.proto\x1a\x14gogoproto/gogo.proto"\xd6\x01\n\x0cGenesisState\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x12e\n\x0cdenom_traces\x18\x02 \x03(\x0b2(.ibc.applications.transfer.v1.DenomTraceB%\xaa\xdf\x1f\x06Traces\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:"denom_traces"\x12:\n\x06params\x18\x03 \x01(\x0b2$.ibc.applications.transfer.v1.ParamsB\x04\xc8\xde\x1f\x00B9Z7github.com/cosmos/ibc-go/v3/modules/apps/transfer/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v3/modules/apps/transfer/types'
    _GENESISSTATE.fields_by_name['port_id']._options = None
    _GENESISSTATE.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _GENESISSTATE.fields_by_name['denom_traces']._options = None
    _GENESISSTATE.fields_by_name['denom_traces']._serialized_options = b'\xaa\xdf\x1f\x06Traces\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:"denom_traces"'
    _GENESISSTATE.fields_by_name['params']._options = None
    _GENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE._serialized_start = 144
    _GENESISSTATE._serialized_end = 358




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....sentinel.deposit.v1 import querier_pb2 as sentinel_dot_deposit_dot_v1_dot_querier__pb2

class QueryServiceStub(object):
    'Missing associated documentation comment in .proto file.'

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.QueryDeposits = channel.unary_unary('/sentinel.deposit.v1.QueryService/QueryDeposits', request_serializer=sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositsRequest.SerializeToString, response_deserializer=sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositsResponse.FromString)
        self.QueryDeposit = channel.unary_unary('/sentinel.deposit.v1.QueryService/QueryDeposit', request_serializer=sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositRequest.SerializeToString, response_deserializer=sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositResponse.FromString)

class QueryServiceServicer(object):
    'Missing associated documentation comment in .proto file.'

    def QueryDeposits(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryDeposit(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'QueryDeposits': grpc.unary_unary_rpc_method_handler(servicer.QueryDeposits, request_deserializer=sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositsRequest.FromString, response_serializer=sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositsResponse.SerializeToString), 'QueryDeposit': grpc.unary_unary_rpc_method_handler(servicer.QueryDeposit, request_deserializer=sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositRequest.FromString, response_serializer=sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('sentinel.deposit.v1.QueryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class QueryService(object):
    'Missing associated documentation comment in .proto file.'

    @staticmethod
    def QueryDeposits(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.deposit.v1.QueryService/QueryDeposits', sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositsRequest.SerializeToString, sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryDeposit(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.deposit.v1.QueryService/QueryDeposit', sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositRequest.SerializeToString, sentinel_dot_deposit_dot_v1_dot_querier__pb2.QueryDepositResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtendermint/types/events.proto\x12\x10tendermint.types"B\n\x13EventDataRoundState\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x0c\n\x04step\x18\x03 \x01(\tB9Z7github.com/tendermint/tendermint/proto/tendermint/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.events_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/types'
    _EVENTDATAROUNDSTATE._serialized_start = 51
    _EVENTDATAROUNDSTATE._serialized_end = 117




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....sentinel.subscription.v2 import querier_pb2 as sentinel_dot_subscription_dot_v2_dot_querier__pb2

class QueryServiceStub(object):
    'Missing associated documentation comment in .proto file.'

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.QuerySubscriptions = channel.unary_unary('/sentinel.subscription.v2.QueryService/QuerySubscriptions', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsResponse.FromString)
        self.QuerySubscriptionsForAccount = channel.unary_unary('/sentinel.subscription.v2.QueryService/QuerySubscriptionsForAccount', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForAccountRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForAccountResponse.FromString)
        self.QuerySubscriptionsForNode = channel.unary_unary('/sentinel.subscription.v2.QueryService/QuerySubscriptionsForNode', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForNodeRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForNodeResponse.FromString)
        self.QuerySubscriptionsForPlan = channel.unary_unary('/sentinel.subscription.v2.QueryService/QuerySubscriptionsForPlan', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForPlanRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForPlanResponse.FromString)
        self.QuerySubscription = channel.unary_unary('/sentinel.subscription.v2.QueryService/QuerySubscription', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionResponse.FromString)
        self.QueryAllocations = channel.unary_unary('/sentinel.subscription.v2.QueryService/QueryAllocations', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationsRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationsResponse.FromString)
        self.QueryAllocation = channel.unary_unary('/sentinel.subscription.v2.QueryService/QueryAllocation', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationResponse.FromString)
        self.QueryPayouts = channel.unary_unary('/sentinel.subscription.v2.QueryService/QueryPayouts', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsResponse.FromString)
        self.QueryPayoutsForAccount = channel.unary_unary('/sentinel.subscription.v2.QueryService/QueryPayoutsForAccount', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForAccountRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForAccountResponse.FromString)
        self.QueryPayoutsForNode = channel.unary_unary('/sentinel.subscription.v2.QueryService/QueryPayoutsForNode', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForNodeRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForNodeResponse.FromString)
        self.QueryPayout = channel.unary_unary('/sentinel.subscription.v2.QueryService/QueryPayout', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutResponse.FromString)
        self.QueryParams = channel.unary_unary('/sentinel.subscription.v2.QueryService/QueryParams', request_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryParamsRequest.SerializeToString, response_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryParamsResponse.FromString)

class QueryServiceServicer(object):
    'Missing associated documentation comment in .proto file.'

    def QuerySubscriptions(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuerySubscriptionsForAccount(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuerySubscriptionsForNode(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuerySubscriptionsForPlan(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuerySubscription(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryAllocations(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryAllocation(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryPayouts(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryPayoutsForAccount(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryPayoutsForNode(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryPayout(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryParams(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'QuerySubscriptions': grpc.unary_unary_rpc_method_handler(servicer.QuerySubscriptions, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsResponse.SerializeToString), 'QuerySubscriptionsForAccount': grpc.unary_unary_rpc_method_handler(servicer.QuerySubscriptionsForAccount, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForAccountRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForAccountResponse.SerializeToString), 'QuerySubscriptionsForNode': grpc.unary_unary_rpc_method_handler(servicer.QuerySubscriptionsForNode, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForNodeRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForNodeResponse.SerializeToString), 'QuerySubscriptionsForPlan': grpc.unary_unary_rpc_method_handler(servicer.QuerySubscriptionsForPlan, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForPlanRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForPlanResponse.SerializeToString), 'QuerySubscription': grpc.unary_unary_rpc_method_handler(servicer.QuerySubscription, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionResponse.SerializeToString), 'QueryAllocations': grpc.unary_unary_rpc_method_handler(servicer.QueryAllocations, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationsRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationsResponse.SerializeToString), 'QueryAllocation': grpc.unary_unary_rpc_method_handler(servicer.QueryAllocation, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationResponse.SerializeToString), 'QueryPayouts': grpc.unary_unary_rpc_method_handler(servicer.QueryPayouts, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsResponse.SerializeToString), 'QueryPayoutsForAccount': grpc.unary_unary_rpc_method_handler(servicer.QueryPayoutsForAccount, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForAccountRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForAccountResponse.SerializeToString), 'QueryPayoutsForNode': grpc.unary_unary_rpc_method_handler(servicer.QueryPayoutsForNode, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForNodeRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForNodeResponse.SerializeToString), 'QueryPayout': grpc.unary_unary_rpc_method_handler(servicer.QueryPayout, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutResponse.SerializeToString), 'QueryParams': grpc.unary_unary_rpc_method_handler(servicer.QueryParams, request_deserializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryParamsRequest.FromString, response_serializer=sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryParamsResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('sentinel.subscription.v2.QueryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class QueryService(object):
    'Missing associated documentation comment in .proto file.'

    @staticmethod
    def QuerySubscriptions(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QuerySubscriptions', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuerySubscriptionsForAccount(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QuerySubscriptionsForAccount', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForAccountRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForAccountResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuerySubscriptionsForNode(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QuerySubscriptionsForNode', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForNodeRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForNodeResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuerySubscriptionsForPlan(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QuerySubscriptionsForPlan', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForPlanRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionsForPlanResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuerySubscription(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QuerySubscription', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QuerySubscriptionResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryAllocations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QueryAllocations', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationsRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryAllocation(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QueryAllocation', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryAllocationResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryPayouts(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QueryPayouts', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryPayoutsForAccount(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QueryPayoutsForAccount', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForAccountRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForAccountResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryPayoutsForNode(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QueryPayoutsForNode', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForNodeRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutsForNodeResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryPayout(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QueryPayout', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryPayoutResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryParams(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.subscription.v2.QueryService/QueryParams', sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryParamsRequest.SerializeToString, sentinel_dot_subscription_dot_v2_dot_querier__pb2.QueryParamsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from sentinel.plan.v2 import plan_pb2 as _plan_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryPlanRequest(_message.Message):
    __slots__ = ['id']
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int

    def __init__(self, id: _Optional[int]=...) -> None:
        ...

class QueryPlanResponse(_message.Message):
    __slots__ = ['plan']
    PLAN_FIELD_NUMBER: _ClassVar[int]
    plan: _plan_pb2.Plan

    def __init__(self, plan: _Optional[_Union[(_plan_pb2.Plan, _Mapping)]]=...) -> None:
        ...

class QueryPlansForProviderRequest(_message.Message):
    __slots__ = ['address', 'pagination', 'status']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    status: _status_pb2.Status

    def __init__(self, address: _Optional[str]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryPlansForProviderResponse(_message.Message):
    __slots__ = ['pagination', 'plans']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PLANS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    plans: _containers.RepeatedCompositeFieldContainer[_plan_pb2.Plan]

    def __init__(self, plans: _Optional[_Iterable[_Union[(_plan_pb2.Plan, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryPlansRequest(_message.Message):
    __slots__ = ['pagination', 'status']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    status: _status_pb2.Status

    def __init__(self, status: _Optional[_Union[(_status_pb2.Status, str)]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryPlansResponse(_message.Message):
    __slots__ = ['pagination', 'plans']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PLANS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    plans: _containers.RepeatedCompositeFieldContainer[_plan_pb2.Plan]

    def __init__(self, plans: _Optional[_Iterable[_Union[(_plan_pb2.Plan, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ibc/applications/transfer/v2/packet.proto\x12\x1cibc.applications.transfer.v2"Z\n\x17FungibleTokenPacketData\x12\r\n\x05denom\x18\x01 \x01(\t\x12\x0e\n\x06amount\x18\x02 \x01(\t\x12\x0e\n\x06sender\x18\x03 \x01(\t\x12\x10\n\x08receiver\x18\x04 \x01(\tB9Z7github.com/cosmos/ibc-go/v3/modules/apps/transfer/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v2.packet_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v3/modules/apps/transfer/types'
    _FUNGIBLETOKENPACKETDATA._serialized_start = 75
    _FUNGIBLETOKENPACKETDATA._serialized_end = 165




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class PrivKey(_message.Message):
    __slots__ = ['secret']
    SECRET_FIELD_NUMBER: _ClassVar[int]
    secret: bytes

    def __init__(self, secret: _Optional[bytes]=...) -> None:
        ...

class PubKey(_message.Message):
    __slots__ = ['key']
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: bytes

    def __init__(self, key: _Optional[bytes]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fcosmos/staking/v1beta1/tx.proto\x12\x16cosmos.staking.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\x1a\x19cosmos_proto/cosmos.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a$cosmos/staking/v1beta1/staking.proto"\xee\x03\n\x12MsgCreateValidator\x12>\n\x0bdescription\x18\x01 \x01(\x0b2#.cosmos.staking.v1beta1.DescriptionB\x04\xc8\xde\x1f\x00\x12A\n\ncommission\x18\x02 \x01(\x0b2\'.cosmos.staking.v1beta1.CommissionRatesB\x04\xc8\xde\x1f\x00\x12i\n\x13min_self_delegation\x18\x03 \x01(\tBL\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:"min_self_delegation"\xc8\xde\x1f\x00\x127\n\x11delegator_address\x18\x04 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x127\n\x11validator_address\x18\x05 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12>\n\x06pubkey\x18\x06 \x01(\x0b2\x14.google.protobuf.AnyB\x18\xca\xb4-\x14cosmos.crypto.PubKey\x12.\n\x05value\x18\x07 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1c\n\x1aMsgCreateValidatorResponse"\xd1\x02\n\x10MsgEditValidator\x12>\n\x0bdescription\x18\x01 \x01(\x0b2#.cosmos.staking.v1beta1.DescriptionB\x04\xc8\xde\x1f\x00\x12-\n\x11validator_address\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12]\n\x0fcommission_rate\x18\x03 \x01(\tBD\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x16yaml:"commission_rate"\x12e\n\x13min_self_delegation\x18\x04 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:"min_self_delegation":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1a\n\x18MsgEditValidatorResponse"\xba\x01\n\x0bMsgDelegate\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x127\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12/\n\x06amount\x18\x03 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x15\n\x13MsgDelegateResponse"\x8a\x02\n\x12MsgBeginRedelegate\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x12?\n\x15validator_src_address\x18\x02 \x01(\tB \xf2\xde\x1f\x1cyaml:"validator_src_address"\x12?\n\x15validator_dst_address\x18\x03 \x01(\tB \xf2\xde\x1f\x1cyaml:"validator_dst_address"\x12/\n\x06amount\x18\x04 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"[\n\x1aMsgBeginRedelegateResponse\x12=\n\x0fcompletion_time\x18\x01 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01"\xbc\x01\n\rMsgUndelegate\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x127\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12/\n\x06amount\x18\x03 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"V\n\x15MsgUndelegateResponse\x12=\n\x0fcompletion_time\x18\x01 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x012\x9a\x04\n\x03Msg\x12q\n\x0fCreateValidator\x12*.cosmos.staking.v1beta1.MsgCreateValidator\x1a2.cosmos.staking.v1beta1.MsgCreateValidatorResponse\x12k\n\rEditValidator\x12(.cosmos.staking.v1beta1.MsgEditValidator\x1a0.cosmos.staking.v1beta1.MsgEditValidatorResponse\x12\\\n\x08Delegate\x12#.cosmos.staking.v1beta1.MsgDelegate\x1a+.cosmos.staking.v1beta1.MsgDelegateResponse\x12q\n\x0fBeginRedelegate\x12*.cosmos.staking.v1beta1.MsgBeginRedelegate\x1a2.cosmos.staking.v1beta1.MsgBeginRedelegateResponse\x12b\n\nUndelegate\x12%.cosmos.staking.v1beta1.MsgUndelegate\x1a-.cosmos.staking.v1beta1.MsgUndelegateResponseB.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
    _MSGCREATEVALIDATOR.fields_by_name['description']._options = None
    _MSGCREATEVALIDATOR.fields_by_name['description']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGCREATEVALIDATOR.fields_by_name['commission']._options = None
    _MSGCREATEVALIDATOR.fields_by_name['commission']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGCREATEVALIDATOR.fields_by_name['min_self_delegation']._options = None
    _MSGCREATEVALIDATOR.fields_by_name['min_self_delegation']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:"min_self_delegation"\xc8\xde\x1f\x00'
    _MSGCREATEVALIDATOR.fields_by_name['delegator_address']._options = None
    _MSGCREATEVALIDATOR.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _MSGCREATEVALIDATOR.fields_by_name['validator_address']._options = None
    _MSGCREATEVALIDATOR.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _MSGCREATEVALIDATOR.fields_by_name['pubkey']._options = None
    _MSGCREATEVALIDATOR.fields_by_name['pubkey']._serialized_options = b'\xca\xb4-\x14cosmos.crypto.PubKey'
    _MSGCREATEVALIDATOR.fields_by_name['value']._options = None
    _MSGCREATEVALIDATOR.fields_by_name['value']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGCREATEVALIDATOR._options = None
    _MSGCREATEVALIDATOR._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGEDITVALIDATOR.fields_by_name['description']._options = None
    _MSGEDITVALIDATOR.fields_by_name['description']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGEDITVALIDATOR.fields_by_name['validator_address']._options = None
    _MSGEDITVALIDATOR.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _MSGEDITVALIDATOR.fields_by_name['commission_rate']._options = None
    _MSGEDITVALIDATOR.fields_by_name['commission_rate']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x16yaml:"commission_rate"'
    _MSGEDITVALIDATOR.fields_by_name['min_self_delegation']._options = None
    _MSGEDITVALIDATOR.fields_by_name['min_self_delegation']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:"min_self_delegation"'
    _MSGEDITVALIDATOR._options = None
    _MSGEDITVALIDATOR._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGDELEGATE.fields_by_name['delegator_address']._options = None
    _MSGDELEGATE.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _MSGDELEGATE.fields_by_name['validator_address']._options = None
    _MSGDELEGATE.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _MSGDELEGATE.fields_by_name['amount']._options = None
    _MSGDELEGATE.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGDELEGATE._options = None
    _MSGDELEGATE._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGBEGINREDELEGATE.fields_by_name['delegator_address']._options = None
    _MSGBEGINREDELEGATE.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _MSGBEGINREDELEGATE.fields_by_name['validator_src_address']._options = None
    _MSGBEGINREDELEGATE.fields_by_name['validator_src_address']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"validator_src_address"'
    _MSGBEGINREDELEGATE.fields_by_name['validator_dst_address']._options = None
    _MSGBEGINREDELEGATE.fields_by_name['validator_dst_address']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"validator_dst_address"'
    _MSGBEGINREDELEGATE.fields_by_name['amount']._options = None
    _MSGBEGINREDELEGATE.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGBEGINREDELEGATE._options = None
    _MSGBEGINREDELEGATE._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGBEGINREDELEGATERESPONSE.fields_by_name['completion_time']._options = None
    _MSGBEGINREDELEGATERESPONSE.fields_by_name['completion_time']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _MSGUNDELEGATE.fields_by_name['delegator_address']._options = None
    _MSGUNDELEGATE.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _MSGUNDELEGATE.fields_by_name['validator_address']._options = None
    _MSGUNDELEGATE.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _MSGUNDELEGATE.fields_by_name['amount']._options = None
    _MSGUNDELEGATE.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGUNDELEGATE._options = None
    _MSGUNDELEGATE._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGUNDELEGATERESPONSE.fields_by_name['completion_time']._options = None
    _MSGUNDELEGATERESPONSE.fields_by_name['completion_time']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _MSGCREATEVALIDATOR._serialized_start = 239
    _MSGCREATEVALIDATOR._serialized_end = 733
    _MSGCREATEVALIDATORRESPONSE._serialized_start = 735
    _MSGCREATEVALIDATORRESPONSE._serialized_end = 763
    _MSGEDITVALIDATOR._serialized_start = 766
    _MSGEDITVALIDATOR._serialized_end = 1103
    _MSGEDITVALIDATORRESPONSE._serialized_start = 1105
    _MSGEDITVALIDATORRESPONSE._serialized_end = 1131
    _MSGDELEGATE._serialized_start = 1134
    _MSGDELEGATE._serialized_end = 1320
    _MSGDELEGATERESPONSE._serialized_start = 1322
    _MSGDELEGATERESPONSE._serialized_end = 1343
    _MSGBEGINREDELEGATE._serialized_start = 1346
    _MSGBEGINREDELEGATE._serialized_end = 1612
    _MSGBEGINREDELEGATERESPONSE._serialized_start = 1614
    _MSGBEGINREDELEGATERESPONSE._serialized_end = 1705
    _MSGUNDELEGATE._serialized_start = 1708
    _MSGUNDELEGATE._serialized_end = 1896
    _MSGUNDELEGATERESPONSE._serialized_start = 1898
    _MSGUNDELEGATERESPONSE._serialized_end = 1984
    _MSG._serialized_start = 1987
    _MSG._serialized_end = 2525




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....sentinel.swap.v1 import swap_pb2 as sentinel_dot_swap_dot_v1_dot_swap__pb2
from ....sentinel.swap.v1 import params_pb2 as sentinel_dot_swap_dot_v1_dot_params__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/swap/v1/querier.proto\x12\x10sentinel.swap.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bsentinel/swap/v1/swap.proto\x1a\x1dsentinel/swap/v1/params.proto"O\n\x11QuerySwapsRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"#\n\x10QuerySwapRequest\x12\x0f\n\x07tx_hash\x18\x01 \x01(\x0c"\x14\n\x12QueryParamsRequest"~\n\x12QuerySwapsResponse\x12+\n\x05swaps\x18\x01 \x03(\x0b2\x16.sentinel.swap.v1.SwapB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"?\n\x11QuerySwapResponse\x12*\n\x04swap\x18\x01 \x01(\x0b2\x16.sentinel.swap.v1.SwapB\x04\xc8\xde\x1f\x00"E\n\x13QueryParamsResponse\x12.\n\x06params\x18\x01 \x01(\x0b2\x18.sentinel.swap.v1.ParamsB\x04\xc8\xde\x1f\x002\xfd\x02\n\x0cQueryService\x12p\n\nQuerySwaps\x12#.sentinel.swap.v1.QuerySwapsRequest\x1a$.sentinel.swap.v1.QuerySwapsResponse"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/swaps\x12w\n\tQuerySwap\x12".sentinel.swap.v1.QuerySwapRequest\x1a#.sentinel.swap.v1.QuerySwapResponse"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/sentinel/swaps/{tx_hash}\x12\x81\x01\n\x0bQueryParams\x12$.sentinel.swap.v1.QueryParamsRequest\x1a%.sentinel.swap.v1.QueryParamsResponse"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/modules/swap/paramsB7Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.swap.v1.querier_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _QUERYSWAPSRESPONSE.fields_by_name['swaps']._options = None
    _QUERYSWAPSRESPONSE.fields_by_name['swaps']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSWAPRESPONSE.fields_by_name['swap']._options = None
    _QUERYSWAPRESPONSE.fields_by_name['swap']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSERVICE.methods_by_name['QuerySwaps']._options = None
    _QUERYSERVICE.methods_by_name['QuerySwaps']._serialized_options = b'\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/swaps'
    _QUERYSERVICE.methods_by_name['QuerySwap']._options = None
    _QUERYSERVICE.methods_by_name['QuerySwap']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1b\x12\x19/sentinel/swaps/{tx_hash}'
    _QUERYSERVICE.methods_by_name['QueryParams']._options = None
    _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/modules/swap/params'
    _QUERYSWAPSREQUEST._serialized_start = 208
    _QUERYSWAPSREQUEST._serialized_end = 287
    _QUERYSWAPREQUEST._serialized_start = 289
    _QUERYSWAPREQUEST._serialized_end = 324
    _QUERYPARAMSREQUEST._serialized_start = 326
    _QUERYPARAMSREQUEST._serialized_end = 346
    _QUERYSWAPSRESPONSE._serialized_start = 348
    _QUERYSWAPSRESPONSE._serialized_end = 474
    _QUERYSWAPRESPONSE._serialized_start = 476
    _QUERYSWAPRESPONSE._serialized_end = 539
    _QUERYPARAMSRESPONSE._serialized_start = 541
    _QUERYPARAMSRESPONSE._serialized_end = 610
    _QUERYSERVICE._serialized_start = 613
    _QUERYSERVICE._serialized_end = 994




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftendermint/rpc/grpc/types.proto\x12\x13tendermint.rpc.grpc\x1a\x1btendermint/abci/types.proto"\r\n\x0bRequestPing" \n\x12RequestBroadcastTx\x12\n\n\x02tx\x18\x01 \x01(\x0c"\x0e\n\x0cResponsePing"\x81\x01\n\x13ResponseBroadcastTx\x122\n\x08check_tx\x18\x01 \x01(\x0b2 .tendermint.abci.ResponseCheckTx\x126\n\ndeliver_tx\x18\x02 \x01(\x0b2".tendermint.abci.ResponseDeliverTx2\xbd\x01\n\x0cBroadcastAPI\x12K\n\x04Ping\x12 .tendermint.rpc.grpc.RequestPing\x1a!.tendermint.rpc.grpc.ResponsePing\x12`\n\x0bBroadcastTx\x12\'.tendermint.rpc.grpc.RequestBroadcastTx\x1a(.tendermint.rpc.grpc.ResponseBroadcastTxB4Z2github.com/tendermint/tendermint/rpc/grpc;coregrpcb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.rpc.grpc.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z2github.com/tendermint/tendermint/rpc/grpc;coregrpc'
    _REQUESTPING._serialized_start = 85
    _REQUESTPING._serialized_end = 98
    _REQUESTBROADCASTTX._serialized_start = 100
    _REQUESTBROADCASTTX._serialized_end = 132
    _RESPONSEPING._serialized_start = 134
    _RESPONSEPING._serialized_end = 148
    _RESPONSEBROADCASTTX._serialized_start = 151
    _RESPONSEBROADCASTTX._serialized_end = 280
    _BROADCASTAPI._serialized_start = 283
    _BROADCASTAPI._serialized_end = 472




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4ibc/applications/interchain_accounts/v1/packet.proto\x12\'ibc.applications.interchain_accounts.v1\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto"v\n\x1bInterchainAccountPacketData\x12;\n\x04type\x18\x01 \x01(\x0e2-.ibc.applications.interchain_accounts.v1.Type\x12\x0c\n\x04data\x18\x02 \x01(\x0c\x12\x0c\n\x04memo\x18\x03 \x01(\t"2\n\x08CosmosTx\x12&\n\x08messages\x18\x01 \x03(\x0b2\x14.google.protobuf.Any*X\n\x04Type\x12%\n\x10TYPE_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12#\n\x0fTYPE_EXECUTE_TX\x10\x01\x1a\x0e\x8a\x9d \nEXECUTE_TX\x1a\x04\x88\xa3\x1e\x00BGZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.v1.packet_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'ZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/types'
    _TYPE._options = None
    _TYPE._serialized_options = b'\x88\xa3\x1e\x00'
    _TYPE.values_by_name['TYPE_UNSPECIFIED']._options = None
    _TYPE.values_by_name['TYPE_UNSPECIFIED']._serialized_options = b'\x8a\x9d \x0bUNSPECIFIED'
    _TYPE.values_by_name['TYPE_EXECUTE_TX']._options = None
    _TYPE.values_by_name['TYPE_EXECUTE_TX']._serialized_options = b'\x8a\x9d \nEXECUTE_TX'
    _TYPE._serialized_start = 318
    _TYPE._serialized_end = 406
    _INTERCHAINACCOUNTPACKETDATA._serialized_start = 146
    _INTERCHAINACCOUNTPACKETDATA._serialized_end = 264
    _COSMOSTX._serialized_start = 266
    _COSMOSTX._serialized_end = 316



from . import abci
from . import blockchain
from . import consensus
from . import crypto
from . import libs
from . import mempool
from . import p2p
from . import privval
from . import rpc
from . import state
from . import statesync
from . import store
from . import types
from . import version




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-cosmos/crypto/multisig/v1beta1/multisig.proto\x12\x1ecosmos.crypto.multisig.v1beta1\x1a\x14gogoproto/gogo.proto"*\n\x0eMultiSignature\x12\x12\n\nsignatures\x18\x01 \x03(\x0c:\x04\xd0\xa1\x1f\x01"A\n\x0fCompactBitArray\x12\x19\n\x11extra_bits_stored\x18\x01 \x01(\r\x12\r\n\x05elems\x18\x02 \x01(\x0c:\x04\x98\xa0\x1f\x00B+Z)github.com/cosmos/cosmos-sdk/crypto/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.multisig.v1beta1.multisig_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/crypto/types'
    _MULTISIGNATURE._options = None
    _MULTISIGNATURE._serialized_options = b'\xd0\xa1\x1f\x01'
    _COMPACTBITARRAY._options = None
    _COMPACTBITARRAY._serialized_options = b'\x98\xa0\x1f\x00'
    _MULTISIGNATURE._serialized_start = 103
    _MULTISIGNATURE._serialized_end = 145
    _COMPACTBITARRAY._serialized_start = 147
    _COMPACTBITARRAY._serialized_end = 212




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.auth.v1beta1 import auth_pb2 as _auth_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class BaseVestingAccount(_message.Message):
    __slots__ = ['base_account', 'delegated_free', 'delegated_vesting', 'end_time', 'original_vesting']
    BASE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    DELEGATED_FREE_FIELD_NUMBER: _ClassVar[int]
    DELEGATED_VESTING_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    ORIGINAL_VESTING_FIELD_NUMBER: _ClassVar[int]
    base_account: _auth_pb2.BaseAccount
    delegated_free: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    delegated_vesting: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    end_time: int
    original_vesting: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]

    def __init__(self, base_account: _Optional[_Union[(_auth_pb2.BaseAccount, _Mapping)]]=..., original_vesting: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., delegated_free: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., delegated_vesting: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., end_time: _Optional[int]=...) -> None:
        ...

class ContinuousVestingAccount(_message.Message):
    __slots__ = ['base_vesting_account', 'start_time']
    BASE_VESTING_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    base_vesting_account: BaseVestingAccount
    start_time: int

    def __init__(self, base_vesting_account: _Optional[_Union[(BaseVestingAccount, _Mapping)]]=..., start_time: _Optional[int]=...) -> None:
        ...

class DelayedVestingAccount(_message.Message):
    __slots__ = ['base_vesting_account']
    BASE_VESTING_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    base_vesting_account: BaseVestingAccount

    def __init__(self, base_vesting_account: _Optional[_Union[(BaseVestingAccount, _Mapping)]]=...) -> None:
        ...

class Period(_message.Message):
    __slots__ = ['amount', 'length']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    LENGTH_FIELD_NUMBER: _ClassVar[int]
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    length: int

    def __init__(self, length: _Optional[int]=..., amount: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=...) -> None:
        ...

class PeriodicVestingAccount(_message.Message):
    __slots__ = ['base_vesting_account', 'start_time', 'vesting_periods']
    BASE_VESTING_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    VESTING_PERIODS_FIELD_NUMBER: _ClassVar[int]
    base_vesting_account: BaseVestingAccount
    start_time: int
    vesting_periods: _containers.RepeatedCompositeFieldContainer[Period]

    def __init__(self, base_vesting_account: _Optional[_Union[(BaseVestingAccount, _Mapping)]]=..., start_time: _Optional[int]=..., vesting_periods: _Optional[_Iterable[_Union[(Period, _Mapping)]]]=...) -> None:
        ...

class PermanentLockedAccount(_message.Message):
    __slots__ = ['base_vesting_account']
    BASE_VESTING_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    base_vesting_account: BaseVestingAccount

    def __init__(self, base_vesting_account: _Optional[_Union[(BaseVestingAccount, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ...tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/types/validator.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/crypto/keys.proto"\x8a\x01\n\x0cValidatorSet\x12/\n\nvalidators\x18\x01 \x03(\x0b2\x1b.tendermint.types.Validator\x12-\n\x08proposer\x18\x02 \x01(\x0b2\x1b.tendermint.types.Validator\x12\x1a\n\x12total_voting_power\x18\x03 \x01(\x03"\x82\x01\n\tValidator\x12\x0f\n\x07address\x18\x01 \x01(\x0c\x123\n\x07pub_key\x18\x02 \x01(\x0b2\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x14\n\x0cvoting_power\x18\x03 \x01(\x03\x12\x19\n\x11proposer_priority\x18\x04 \x01(\x03"V\n\x0fSimpleValidator\x12-\n\x07pub_key\x18\x01 \x01(\x0b2\x1c.tendermint.crypto.PublicKey\x12\x14\n\x0cvoting_power\x18\x02 \x01(\x03B9Z7github.com/tendermint/tendermint/proto/tendermint/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.validator_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/types'
    _VALIDATOR.fields_by_name['pub_key']._options = None
    _VALIDATOR.fields_by_name['pub_key']._serialized_options = b'\xc8\xde\x1f\x00'
    _VALIDATORSET._serialized_start = 107
    _VALIDATORSET._serialized_end = 245
    _VALIDATOR._serialized_start = 248
    _VALIDATOR._serialized_end = 378
    _SIMPLEVALIDATOR._serialized_start = 380
    _SIMPLEVALIDATOR._serialized_end = 466




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class App(_message.Message):
    __slots__ = ['protocol', 'software']
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_FIELD_NUMBER: _ClassVar[int]
    protocol: int
    software: str

    def __init__(self, protocol: _Optional[int]=..., software: _Optional[str]=...) -> None:
        ...

class Consensus(_message.Message):
    __slots__ = ['app', 'block']
    APP_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    app: int
    block: int

    def __init__(self, block: _Optional[int]=..., app: _Optional[int]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/evidence/v1beta1/tx.proto\x12\x17cosmos.evidence.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19cosmos_proto/cosmos.proto"f\n\x11MsgSubmitEvidence\x12\x11\n\tsubmitter\x18\x01 \x01(\t\x124\n\x08evidence\x18\x02 \x01(\x0b2\x14.google.protobuf.AnyB\x0c\xca\xb4-\x08Evidence:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00")\n\x19MsgSubmitEvidenceResponse\x12\x0c\n\x04hash\x18\x04 \x01(\x0c2w\n\x03Msg\x12p\n\x0eSubmitEvidence\x12*.cosmos.evidence.v1beta1.MsgSubmitEvidence\x1a2.cosmos.evidence.v1beta1.MsgSubmitEvidenceResponseB3Z-github.com/cosmos/cosmos-sdk/x/evidence/types\xa8\xe2\x1e\x01b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/evidence/types\xa8\xe2\x1e\x01'
    _MSGSUBMITEVIDENCE.fields_by_name['evidence']._options = None
    _MSGSUBMITEVIDENCE.fields_by_name['evidence']._serialized_options = b'\xca\xb4-\x08Evidence'
    _MSGSUBMITEVIDENCE._options = None
    _MSGSUBMITEVIDENCE._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGSUBMITEVIDENCE._serialized_start = 137
    _MSGSUBMITEVIDENCE._serialized_end = 239
    _MSGSUBMITEVIDENCERESPONSE._serialized_start = 241
    _MSGSUBMITEVIDENCERESPONSE._serialized_end = 282
    _MSG._serialized_start = 284
    _MSG._serialized_end = 403




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....cosmos.gov.v1beta1 import gov_pb2 as cosmos_dot_gov_dot_v1beta1_dot_gov__pb2
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bcosmos/gov/v1beta1/tx.proto\x12\x12cosmos.gov.v1beta1\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x1ccosmos/gov/v1beta1/gov.proto\x1a\x19cosmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto"\xeb\x01\n\x11MsgSubmitProposal\x122\n\x07content\x18\x01 \x01(\x0b2\x14.google.protobuf.AnyB\x0b\xca\xb4-\x07Content\x12~\n\x0finitial_deposit\x18\x02 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinBJ\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x16yaml:"initial_deposit"\x12\x10\n\x08proposer\x18\x03 \x01(\t:\x10\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00"W\n\x19MsgSubmitProposalResponse\x12:\n\x0bproposal_id\x18\x01 \x01(\x04B%\xea\xde\x1f\x0bproposal_id\xf2\xde\x1f\x12yaml:"proposal_id""\x96\x01\n\x07MsgVote\x12:\n\x0bproposal_id\x18\x01 \x01(\x04B%\xea\xde\x1f\x0bproposal_id\xf2\xde\x1f\x12yaml:"proposal_id"\x12\r\n\x05voter\x18\x02 \x01(\t\x12.\n\x06option\x18\x03 \x01(\x0e2\x1e.cosmos.gov.v1beta1.VoteOption:\x10\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00"\x11\n\x0fMsgVoteResponse"\x9e\x01\n\x0fMsgVoteWeighted\x12+\n\x0bproposal_id\x18\x01 \x01(\x04B\x16\xf2\xde\x1f\x12yaml:"proposal_id"\x12\r\n\x05voter\x18\x02 \x01(\t\x12=\n\x07options\x18\x03 \x03(\x0b2&.cosmos.gov.v1beta1.WeightedVoteOptionB\x04\xc8\xde\x1f\x00:\x10\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00"\x19\n\x17MsgVoteWeightedResponse"\xca\x01\n\nMsgDeposit\x12:\n\x0bproposal_id\x18\x01 \x01(\x04B%\xea\xde\x1f\x0bproposal_id\xf2\xde\x1f\x12yaml:"proposal_id"\x12\x11\n\tdepositor\x18\x02 \x01(\t\x12[\n\x06amount\x18\x03 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x10\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00"\x14\n\x12MsgDepositResponse2\xec\x02\n\x03Msg\x12f\n\x0eSubmitProposal\x12%.cosmos.gov.v1beta1.MsgSubmitProposal\x1a-.cosmos.gov.v1beta1.MsgSubmitProposalResponse\x12H\n\x04Vote\x12\x1b.cosmos.gov.v1beta1.MsgVote\x1a#.cosmos.gov.v1beta1.MsgVoteResponse\x12`\n\x0cVoteWeighted\x12#.cosmos.gov.v1beta1.MsgVoteWeighted\x1a+.cosmos.gov.v1beta1.MsgVoteWeightedResponse\x12Q\n\x07Deposit\x12\x1e.cosmos.gov.v1beta1.MsgDeposit\x1a&.cosmos.gov.v1beta1.MsgDepositResponseB*Z(github.com/cosmos/cosmos-sdk/x/gov/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1beta1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/x/gov/types'
    _MSGSUBMITPROPOSAL.fields_by_name['content']._options = None
    _MSGSUBMITPROPOSAL.fields_by_name['content']._serialized_options = b'\xca\xb4-\x07Content'
    _MSGSUBMITPROPOSAL.fields_by_name['initial_deposit']._options = None
    _MSGSUBMITPROPOSAL.fields_by_name['initial_deposit']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x16yaml:"initial_deposit"'
    _MSGSUBMITPROPOSAL._options = None
    _MSGSUBMITPROPOSAL._serialized_options = b'\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00'
    _MSGSUBMITPROPOSALRESPONSE.fields_by_name['proposal_id']._options = None
    _MSGSUBMITPROPOSALRESPONSE.fields_by_name['proposal_id']._serialized_options = b'\xea\xde\x1f\x0bproposal_id\xf2\xde\x1f\x12yaml:"proposal_id"'
    _MSGVOTE.fields_by_name['proposal_id']._options = None
    _MSGVOTE.fields_by_name['proposal_id']._serialized_options = b'\xea\xde\x1f\x0bproposal_id\xf2\xde\x1f\x12yaml:"proposal_id"'
    _MSGVOTE._options = None
    _MSGVOTE._serialized_options = b'\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00'
    _MSGVOTEWEIGHTED.fields_by_name['proposal_id']._options = None
    _MSGVOTEWEIGHTED.fields_by_name['proposal_id']._serialized_options = b'\xf2\xde\x1f\x12yaml:"proposal_id"'
    _MSGVOTEWEIGHTED.fields_by_name['options']._options = None
    _MSGVOTEWEIGHTED.fields_by_name['options']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGVOTEWEIGHTED._options = None
    _MSGVOTEWEIGHTED._serialized_options = b'\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00'
    _MSGDEPOSIT.fields_by_name['proposal_id']._options = None
    _MSGDEPOSIT.fields_by_name['proposal_id']._serialized_options = b'\xea\xde\x1f\x0bproposal_id\xf2\xde\x1f\x12yaml:"proposal_id"'
    _MSGDEPOSIT.fields_by_name['amount']._options = None
    _MSGDEPOSIT.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _MSGDEPOSIT._options = None
    _MSGDEPOSIT._serialized_options = b'\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00'
    _MSGSUBMITPROPOSAL._serialized_start = 190
    _MSGSUBMITPROPOSAL._serialized_end = 425
    _MSGSUBMITPROPOSALRESPONSE._serialized_start = 427
    _MSGSUBMITPROPOSALRESPONSE._serialized_end = 514
    _MSGVOTE._serialized_start = 517
    _MSGVOTE._serialized_end = 667
    _MSGVOTERESPONSE._serialized_start = 669
    _MSGVOTERESPONSE._serialized_end = 686
    _MSGVOTEWEIGHTED._serialized_start = 689
    _MSGVOTEWEIGHTED._serialized_end = 847
    _MSGVOTEWEIGHTEDRESPONSE._serialized_start = 849
    _MSGVOTEWEIGHTEDRESPONSE._serialized_end = 874
    _MSGDEPOSIT._serialized_start = 877
    _MSGDEPOSIT._serialized_end = 1079
    _MSGDEPOSITRESPONSE._serialized_start = 1081
    _MSGDEPOSITRESPONSE._serialized_end = 1101
    _MSG._serialized_start = 1104
    _MSG._serialized_end = 1468




from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.gov.v1beta1 import gov_pb2 as _gov_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgDeposit(_message.Message):
    __slots__ = ['amount', 'depositor', 'proposal_id']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DEPOSITOR_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    depositor: str
    proposal_id: int

    def __init__(self, proposal_id: _Optional[int]=..., depositor: _Optional[str]=..., amount: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=...) -> None:
        ...

class MsgDepositResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgSubmitProposal(_message.Message):
    __slots__ = ['content', 'initial_deposit', 'proposer']
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    INITIAL_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_FIELD_NUMBER: _ClassVar[int]
    content: _any_pb2.Any
    initial_deposit: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    proposer: str

    def __init__(self, content: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., initial_deposit: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., proposer: _Optional[str]=...) -> None:
        ...

class MsgSubmitProposalResponse(_message.Message):
    __slots__ = ['proposal_id']
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int

    def __init__(self, proposal_id: _Optional[int]=...) -> None:
        ...

class MsgVote(_message.Message):
    __slots__ = ['option', 'proposal_id', 'voter']
    OPTION_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    option: _gov_pb2.VoteOption
    proposal_id: int
    voter: str

    def __init__(self, proposal_id: _Optional[int]=..., voter: _Optional[str]=..., option: _Optional[_Union[(_gov_pb2.VoteOption, str)]]=...) -> None:
        ...

class MsgVoteResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgVoteWeighted(_message.Message):
    __slots__ = ['options', 'proposal_id', 'voter']
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    options: _containers.RepeatedCompositeFieldContainer[_gov_pb2.WeightedVoteOption]
    proposal_id: int
    voter: str

    def __init__(self, proposal_id: _Optional[int]=..., voter: _Optional[str]=..., options: _Optional[_Iterable[_Union[(_gov_pb2.WeightedVoteOption, _Mapping)]]]=...) -> None:
        ...

class MsgVoteWeightedResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asentinel/swap/v1/msg.proto\x12\x10sentinel.swap.v1\x1a\x14gogoproto/gogo.proto"\x80\x01\n\x0eMsgSwapRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x0f\n\x07tx_hash\x18\x02 \x01(\x0c\x12\x10\n\x08receiver\x18\x03 \x01(\t\x12>\n\x06amount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00"\x11\n\x0fMsgSwapResponse2\\\n\nMsgService\x12N\n\x07MsgSwap\x12 .sentinel.swap.v1.MsgSwapRequest\x1a!.sentinel.swap.v1.MsgSwapResponseB7Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.swap.v1.msg_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _MSGSWAPREQUEST.fields_by_name['amount']._options = None
    _MSGSWAPREQUEST.fields_by_name['amount']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _MSGSWAPREQUEST._serialized_start = 71
    _MSGSWAPREQUEST._serialized_end = 199
    _MSGSWAPRESPONSE._serialized_start = 201
    _MSGSWAPRESPONSE._serialized_end = 218
    _MSGSERVICE._serialized_start = 220
    _MSGSERVICE._serialized_end = 312




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from .....cosmos.base.tendermint.v1beta1 import query_pb2 as cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2

class ServiceStub(object):
    'Service defines the gRPC querier service for tendermint queries.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.GetNodeInfo = channel.unary_unary('/cosmos.base.tendermint.v1beta1.Service/GetNodeInfo', request_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetNodeInfoRequest.SerializeToString, response_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetNodeInfoResponse.FromString)
        self.GetSyncing = channel.unary_unary('/cosmos.base.tendermint.v1beta1.Service/GetSyncing', request_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetSyncingRequest.SerializeToString, response_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetSyncingResponse.FromString)
        self.GetLatestBlock = channel.unary_unary('/cosmos.base.tendermint.v1beta1.Service/GetLatestBlock', request_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestBlockRequest.SerializeToString, response_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestBlockResponse.FromString)
        self.GetBlockByHeight = channel.unary_unary('/cosmos.base.tendermint.v1beta1.Service/GetBlockByHeight', request_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetBlockByHeightRequest.SerializeToString, response_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetBlockByHeightResponse.FromString)
        self.GetLatestValidatorSet = channel.unary_unary('/cosmos.base.tendermint.v1beta1.Service/GetLatestValidatorSet', request_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestValidatorSetRequest.SerializeToString, response_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestValidatorSetResponse.FromString)
        self.GetValidatorSetByHeight = channel.unary_unary('/cosmos.base.tendermint.v1beta1.Service/GetValidatorSetByHeight', request_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetValidatorSetByHeightRequest.SerializeToString, response_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetValidatorSetByHeightResponse.FromString)

class ServiceServicer(object):
    'Service defines the gRPC querier service for tendermint queries.\n    '

    def GetNodeInfo(self, request, context):
        'GetNodeInfo queries the current node info.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSyncing(self, request, context):
        'GetSyncing queries node syncing.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestBlock(self, request, context):
        'GetLatestBlock returns the latest block.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByHeight(self, request, context):
        'GetBlockByHeight queries block for given height.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestValidatorSet(self, request, context):
        'GetLatestValidatorSet queries latest validator-set.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetValidatorSetByHeight(self, request, context):
        'GetValidatorSetByHeight queries validator-set at a given height.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_ServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetNodeInfo': grpc.unary_unary_rpc_method_handler(servicer.GetNodeInfo, request_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetNodeInfoRequest.FromString, response_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetNodeInfoResponse.SerializeToString), 'GetSyncing': grpc.unary_unary_rpc_method_handler(servicer.GetSyncing, request_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetSyncingRequest.FromString, response_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetSyncingResponse.SerializeToString), 'GetLatestBlock': grpc.unary_unary_rpc_method_handler(servicer.GetLatestBlock, request_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestBlockRequest.FromString, response_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestBlockResponse.SerializeToString), 'GetBlockByHeight': grpc.unary_unary_rpc_method_handler(servicer.GetBlockByHeight, request_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetBlockByHeightRequest.FromString, response_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetBlockByHeightResponse.SerializeToString), 'GetLatestValidatorSet': grpc.unary_unary_rpc_method_handler(servicer.GetLatestValidatorSet, request_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestValidatorSetRequest.FromString, response_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestValidatorSetResponse.SerializeToString), 'GetValidatorSetByHeight': grpc.unary_unary_rpc_method_handler(servicer.GetValidatorSetByHeight, request_deserializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetValidatorSetByHeightRequest.FromString, response_serializer=cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetValidatorSetByHeightResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('cosmos.base.tendermint.v1beta1.Service', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Service(object):
    'Service defines the gRPC querier service for tendermint queries.\n    '

    @staticmethod
    def GetNodeInfo(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.base.tendermint.v1beta1.Service/GetNodeInfo', cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetNodeInfoRequest.SerializeToString, cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetNodeInfoResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSyncing(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.base.tendermint.v1beta1.Service/GetSyncing', cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetSyncingRequest.SerializeToString, cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetSyncingResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestBlock(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.base.tendermint.v1beta1.Service/GetLatestBlock', cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestBlockRequest.SerializeToString, cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestBlockResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockByHeight(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.base.tendermint.v1beta1.Service/GetBlockByHeight', cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetBlockByHeightRequest.SerializeToString, cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetBlockByHeightResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestValidatorSet(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.base.tendermint.v1beta1.Service/GetLatestValidatorSet', cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestValidatorSetRequest.SerializeToString, cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetLatestValidatorSetResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetValidatorSetByHeight(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.base.tendermint.v1beta1.Service/GetValidatorSetByHeight', cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetValidatorSetByHeightRequest.SerializeToString, cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_query__pb2.GetValidatorSetByHeightResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




from tendermint.crypto import keys_pb2 as _keys_pb2
from tendermint.types import types_pb2 as _types_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor
ERRORS_CONNECTION_TIMEOUT: Errors
ERRORS_NO_CONNECTION: Errors
ERRORS_READ_TIMEOUT: Errors
ERRORS_UNEXPECTED_RESPONSE: Errors
ERRORS_UNKNOWN: Errors
ERRORS_WRITE_TIMEOUT: Errors

class Message(_message.Message):
    __slots__ = ['ping_request', 'ping_response', 'pub_key_request', 'pub_key_response', 'sign_proposal_request', 'sign_vote_request', 'signed_proposal_response', 'signed_vote_response']
    PING_REQUEST_FIELD_NUMBER: _ClassVar[int]
    PING_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_REQUEST_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    SIGNED_PROPOSAL_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    SIGNED_VOTE_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    SIGN_PROPOSAL_REQUEST_FIELD_NUMBER: _ClassVar[int]
    SIGN_VOTE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    ping_request: PingRequest
    ping_response: PingResponse
    pub_key_request: PubKeyRequest
    pub_key_response: PubKeyResponse
    sign_proposal_request: SignProposalRequest
    sign_vote_request: SignVoteRequest
    signed_proposal_response: SignedProposalResponse
    signed_vote_response: SignedVoteResponse

    def __init__(self, pub_key_request: _Optional[_Union[(PubKeyRequest, _Mapping)]]=..., pub_key_response: _Optional[_Union[(PubKeyResponse, _Mapping)]]=..., sign_vote_request: _Optional[_Union[(SignVoteRequest, _Mapping)]]=..., signed_vote_response: _Optional[_Union[(SignedVoteResponse, _Mapping)]]=..., sign_proposal_request: _Optional[_Union[(SignProposalRequest, _Mapping)]]=..., signed_proposal_response: _Optional[_Union[(SignedProposalResponse, _Mapping)]]=..., ping_request: _Optional[_Union[(PingRequest, _Mapping)]]=..., ping_response: _Optional[_Union[(PingResponse, _Mapping)]]=...) -> None:
        ...

class PingRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class PingResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class PubKeyRequest(_message.Message):
    __slots__ = ['chain_id']
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    chain_id: str

    def __init__(self, chain_id: _Optional[str]=...) -> None:
        ...

class PubKeyResponse(_message.Message):
    __slots__ = ['error', 'pub_key']
    ERROR_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    error: RemoteSignerError
    pub_key: _keys_pb2.PublicKey

    def __init__(self, pub_key: _Optional[_Union[(_keys_pb2.PublicKey, _Mapping)]]=..., error: _Optional[_Union[(RemoteSignerError, _Mapping)]]=...) -> None:
        ...

class RemoteSignerError(_message.Message):
    __slots__ = ['code', 'description']
    CODE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    code: int
    description: str

    def __init__(self, code: _Optional[int]=..., description: _Optional[str]=...) -> None:
        ...

class SignProposalRequest(_message.Message):
    __slots__ = ['chain_id', 'proposal']
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    chain_id: str
    proposal: _types_pb2.Proposal

    def __init__(self, proposal: _Optional[_Union[(_types_pb2.Proposal, _Mapping)]]=..., chain_id: _Optional[str]=...) -> None:
        ...

class SignVoteRequest(_message.Message):
    __slots__ = ['chain_id', 'vote']
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    chain_id: str
    vote: _types_pb2.Vote

    def __init__(self, vote: _Optional[_Union[(_types_pb2.Vote, _Mapping)]]=..., chain_id: _Optional[str]=...) -> None:
        ...

class SignedProposalResponse(_message.Message):
    __slots__ = ['error', 'proposal']
    ERROR_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    error: RemoteSignerError
    proposal: _types_pb2.Proposal

    def __init__(self, proposal: _Optional[_Union[(_types_pb2.Proposal, _Mapping)]]=..., error: _Optional[_Union[(RemoteSignerError, _Mapping)]]=...) -> None:
        ...

class SignedVoteResponse(_message.Message):
    __slots__ = ['error', 'vote']
    ERROR_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    error: RemoteSignerError
    vote: _types_pb2.Vote

    def __init__(self, vote: _Optional[_Union[(_types_pb2.Vote, _Mapping)]]=..., error: _Optional[_Union[(RemoteSignerError, _Mapping)]]=...) -> None:
        ...

class Errors(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class Provider(_message.Message):
    __slots__ = ['address', 'description', 'identity', 'name', 'website']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    WEBSITE_FIELD_NUMBER: _ClassVar[int]
    address: str
    description: str
    identity: str
    name: str
    website: str

    def __init__(self, address: _Optional[str]=..., name: _Optional[str]=..., identity: _Optional[str]=..., website: _Optional[str]=..., description: _Optional[str]=...) -> None:
        ...




from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class ChunkRequest(_message.Message):
    __slots__ = ['format', 'height', 'index']
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    format: int
    height: int
    index: int

    def __init__(self, height: _Optional[int]=..., format: _Optional[int]=..., index: _Optional[int]=...) -> None:
        ...

class ChunkResponse(_message.Message):
    __slots__ = ['chunk', 'format', 'height', 'index', 'missing']
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    format: int
    height: int
    index: int
    missing: bool

    def __init__(self, height: _Optional[int]=..., format: _Optional[int]=..., index: _Optional[int]=..., chunk: _Optional[bytes]=..., missing: bool=...) -> None:
        ...

class Message(_message.Message):
    __slots__ = ['chunk_request', 'chunk_response', 'snapshots_request', 'snapshots_response']
    CHUNK_REQUEST_FIELD_NUMBER: _ClassVar[int]
    CHUNK_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOTS_REQUEST_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOTS_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    chunk_request: ChunkRequest
    chunk_response: ChunkResponse
    snapshots_request: SnapshotsRequest
    snapshots_response: SnapshotsResponse

    def __init__(self, snapshots_request: _Optional[_Union[(SnapshotsRequest, _Mapping)]]=..., snapshots_response: _Optional[_Union[(SnapshotsResponse, _Mapping)]]=..., chunk_request: _Optional[_Union[(ChunkRequest, _Mapping)]]=..., chunk_response: _Optional[_Union[(ChunkResponse, _Mapping)]]=...) -> None:
        ...

class SnapshotsRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class SnapshotsResponse(_message.Message):
    __slots__ = ['chunks', 'format', 'hash', 'height', 'metadata']
    CHUNKS_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    chunks: int
    format: int
    hash: bytes
    height: int
    metadata: bytes

    def __init__(self, height: _Optional[int]=..., format: _Optional[int]=..., chunks: _Optional[int]=..., hash: _Optional[bytes]=..., metadata: _Optional[bytes]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from ...tendermint.types import validator_pb2 as tendermint_dot_types_dot_validator__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftendermint/types/evidence.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ctendermint/types/types.proto\x1a tendermint/types/validator.proto"\xb2\x01\n\x08Evidence\x12J\n\x17duplicate_vote_evidence\x18\x01 \x01(\x0b2\'.tendermint.types.DuplicateVoteEvidenceH\x00\x12S\n\x1clight_client_attack_evidence\x18\x02 \x01(\x0b2+.tendermint.types.LightClientAttackEvidenceH\x00B\x05\n\x03sum"\xd5\x01\n\x15DuplicateVoteEvidence\x12&\n\x06vote_a\x18\x01 \x01(\x0b2\x16.tendermint.types.Vote\x12&\n\x06vote_b\x18\x02 \x01(\x0b2\x16.tendermint.types.Vote\x12\x1a\n\x12total_voting_power\x18\x03 \x01(\x03\x12\x17\n\x0fvalidator_power\x18\x04 \x01(\x03\x127\n\ttimestamp\x18\x05 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01"\xfb\x01\n\x19LightClientAttackEvidence\x127\n\x11conflicting_block\x18\x01 \x01(\x0b2\x1c.tendermint.types.LightBlock\x12\x15\n\rcommon_height\x18\x02 \x01(\x03\x129\n\x14byzantine_validators\x18\x03 \x03(\x0b2\x1b.tendermint.types.Validator\x12\x1a\n\x12total_voting_power\x18\x04 \x01(\x03\x127\n\ttimestamp\x18\x05 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01"B\n\x0cEvidenceList\x122\n\x08evidence\x18\x01 \x03(\x0b2\x1a.tendermint.types.EvidenceB\x04\xc8\xde\x1f\x00B9Z7github.com/tendermint/tendermint/proto/tendermint/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.evidence_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/types'
    _DUPLICATEVOTEEVIDENCE.fields_by_name['timestamp']._options = None
    _DUPLICATEVOTEEVIDENCE.fields_by_name['timestamp']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _LIGHTCLIENTATTACKEVIDENCE.fields_by_name['timestamp']._options = None
    _LIGHTCLIENTATTACKEVIDENCE.fields_by_name['timestamp']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _EVIDENCELIST.fields_by_name['evidence']._options = None
    _EVIDENCELIST.fields_by_name['evidence']._serialized_options = b'\xc8\xde\x1f\x00'
    _EVIDENCE._serialized_start = 173
    _EVIDENCE._serialized_end = 351
    _DUPLICATEVOTEEVIDENCE._serialized_start = 354
    _DUPLICATEVOTEEVIDENCE._serialized_end = 567
    _LIGHTCLIENTATTACKEVIDENCE._serialized_start = 570
    _LIGHTCLIENTATTACKEVIDENCE._serialized_end = 821
    _EVIDENCELIST._serialized_start = 823
    _EVIDENCELIST._serialized_end = 889




from google.protobuf import any_pb2 as _any_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class CancelSoftwareUpgradeProposal(_message.Message):
    __slots__ = ['description', 'title']
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    description: str
    title: str

    def __init__(self, title: _Optional[str]=..., description: _Optional[str]=...) -> None:
        ...

class ModuleVersion(_message.Message):
    __slots__ = ['name', 'version']
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    name: str
    version: int

    def __init__(self, name: _Optional[str]=..., version: _Optional[int]=...) -> None:
        ...

class Plan(_message.Message):
    __slots__ = ['height', 'info', 'name', 'time', 'upgraded_client_state']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    UPGRADED_CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    height: int
    info: str
    name: str
    time: _timestamp_pb2.Timestamp
    upgraded_client_state: _any_pb2.Any

    def __init__(self, name: _Optional[str]=..., time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., height: _Optional[int]=..., info: _Optional[str]=..., upgraded_client_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=...) -> None:
        ...

class SoftwareUpgradeProposal(_message.Message):
    __slots__ = ['description', 'plan', 'title']
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    description: str
    plan: Plan
    title: str

    def __init__(self, title: _Optional[str]=..., description: _Optional[str]=..., plan: _Optional[_Union[(Plan, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tendermint.types import types_pb2 as _types_pb2
from tendermint.types import validator_pb2 as _validator_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class DuplicateVoteEvidence(_message.Message):
    __slots__ = ['timestamp', 'total_voting_power', 'validator_power', 'vote_a', 'vote_b']
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_POWER_FIELD_NUMBER: _ClassVar[int]
    VOTE_A_FIELD_NUMBER: _ClassVar[int]
    VOTE_B_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    total_voting_power: int
    validator_power: int
    vote_a: _types_pb2.Vote
    vote_b: _types_pb2.Vote

    def __init__(self, vote_a: _Optional[_Union[(_types_pb2.Vote, _Mapping)]]=..., vote_b: _Optional[_Union[(_types_pb2.Vote, _Mapping)]]=..., total_voting_power: _Optional[int]=..., validator_power: _Optional[int]=..., timestamp: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...

class Evidence(_message.Message):
    __slots__ = ['duplicate_vote_evidence', 'light_client_attack_evidence']
    DUPLICATE_VOTE_EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    LIGHT_CLIENT_ATTACK_EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    duplicate_vote_evidence: DuplicateVoteEvidence
    light_client_attack_evidence: LightClientAttackEvidence

    def __init__(self, duplicate_vote_evidence: _Optional[_Union[(DuplicateVoteEvidence, _Mapping)]]=..., light_client_attack_evidence: _Optional[_Union[(LightClientAttackEvidence, _Mapping)]]=...) -> None:
        ...

class EvidenceList(_message.Message):
    __slots__ = ['evidence']
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    evidence: _containers.RepeatedCompositeFieldContainer[Evidence]

    def __init__(self, evidence: _Optional[_Iterable[_Union[(Evidence, _Mapping)]]]=...) -> None:
        ...

class LightClientAttackEvidence(_message.Message):
    __slots__ = ['byzantine_validators', 'common_height', 'conflicting_block', 'timestamp', 'total_voting_power']
    BYZANTINE_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    COMMON_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    CONFLICTING_BLOCK_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    byzantine_validators: _containers.RepeatedCompositeFieldContainer[_validator_pb2.Validator]
    common_height: int
    conflicting_block: _types_pb2.LightBlock
    timestamp: _timestamp_pb2.Timestamp
    total_voting_power: int

    def __init__(self, conflicting_block: _Optional[_Union[(_types_pb2.LightBlock, _Mapping)]]=..., common_height: _Optional[int]=..., byzantine_validators: _Optional[_Iterable[_Union[(_validator_pb2.Validator, _Mapping)]]]=..., total_voting_power: _Optional[int]=..., timestamp: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.gov.v1beta1 import gov_pb2 as cosmos_dot_gov_dot_v1beta1_dot_gov__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ecosmos/gov/v1beta1/query.proto\x12\x12cosmos.gov.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1ccosmos/gov/v1beta1/gov.proto"+\n\x14QueryProposalRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04"M\n\x15QueryProposalResponse\x124\n\x08proposal\x18\x01 \x01(\x0b2\x1c.cosmos.gov.v1beta1.ProposalB\x04\xc8\xde\x1f\x00"\xbc\x01\n\x15QueryProposalsRequest\x12;\n\x0fproposal_status\x18\x01 \x01(\x0e2".cosmos.gov.v1beta1.ProposalStatus\x12\r\n\x05voter\x18\x02 \x01(\t\x12\x11\n\tdepositor\x18\x03 \x01(\t\x12:\n\npagination\x18\x04 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x8c\x01\n\x16QueryProposalsResponse\x125\n\tproposals\x18\x01 \x03(\x0b2\x1c.cosmos.gov.v1beta1.ProposalB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"@\n\x10QueryVoteRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\r\n\x05voter\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"A\n\x11QueryVoteResponse\x12,\n\x04vote\x18\x01 \x01(\x0b2\x18.cosmos.gov.v1beta1.VoteB\x04\xc8\xde\x1f\x00"d\n\x11QueryVotesRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x80\x01\n\x12QueryVotesResponse\x12-\n\x05votes\x18\x01 \x03(\x0b2\x18.cosmos.gov.v1beta1.VoteB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse")\n\x12QueryParamsRequest\x12\x13\n\x0bparams_type\x18\x01 \x01(\t"\xd2\x01\n\x13QueryParamsResponse\x12=\n\rvoting_params\x18\x01 \x01(\x0b2 .cosmos.gov.v1beta1.VotingParamsB\x04\xc8\xde\x1f\x00\x12?\n\x0edeposit_params\x18\x02 \x01(\x0b2!.cosmos.gov.v1beta1.DepositParamsB\x04\xc8\xde\x1f\x00\x12;\n\x0ctally_params\x18\x03 \x01(\x0b2\x1f.cosmos.gov.v1beta1.TallyParamsB\x04\xc8\xde\x1f\x00"G\n\x13QueryDepositRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\x11\n\tdepositor\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00"J\n\x14QueryDepositResponse\x122\n\x07deposit\x18\x01 \x01(\x0b2\x1b.cosmos.gov.v1beta1.DepositB\x04\xc8\xde\x1f\x00"g\n\x14QueryDepositsRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x89\x01\n\x15QueryDepositsResponse\x123\n\x08deposits\x18\x01 \x03(\x0b2\x1b.cosmos.gov.v1beta1.DepositB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse".\n\x17QueryTallyResultRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04"P\n\x18QueryTallyResultResponse\x124\n\x05tally\x18\x01 \x01(\x0b2\x1f.cosmos.gov.v1beta1.TallyResultB\x04\xc8\xde\x1f\x002\xd4\t\n\x05Query\x12\x94\x01\n\x08Proposal\x12(.cosmos.gov.v1beta1.QueryProposalRequest\x1a).cosmos.gov.v1beta1.QueryProposalResponse"3\x82\xd3\xe4\x93\x02-\x12+/cosmos/gov/v1beta1/proposals/{proposal_id}\x12\x89\x01\n\tProposals\x12).cosmos.gov.v1beta1.QueryProposalsRequest\x1a*.cosmos.gov.v1beta1.QueryProposalsResponse"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/gov/v1beta1/proposals\x12\x96\x01\n\x04Vote\x12$.cosmos.gov.v1beta1.QueryVoteRequest\x1a%.cosmos.gov.v1beta1.QueryVoteResponse"A\x82\xd3\xe4\x93\x02;\x129/cosmos/gov/v1beta1/proposals/{proposal_id}/votes/{voter}\x12\x91\x01\n\x05Votes\x12%.cosmos.gov.v1beta1.QueryVotesRequest\x1a&.cosmos.gov.v1beta1.QueryVotesResponse"9\x82\xd3\xe4\x93\x023\x121/cosmos/gov/v1beta1/proposals/{proposal_id}/votes\x12\x8b\x01\n\x06Params\x12&.cosmos.gov.v1beta1.QueryParamsRequest\x1a\'.cosmos.gov.v1beta1.QueryParamsResponse"0\x82\xd3\xe4\x93\x02*\x12(/cosmos/gov/v1beta1/params/{params_type}\x12\xa6\x01\n\x07Deposit\x12\'.cosmos.gov.v1beta1.QueryDepositRequest\x1a(.cosmos.gov.v1beta1.QueryDepositResponse"H\x82\xd3\xe4\x93\x02B\x12@/cosmos/gov/v1beta1/proposals/{proposal_id}/deposits/{depositor}\x12\x9d\x01\n\x08Deposits\x12(.cosmos.gov.v1beta1.QueryDepositsRequest\x1a).cosmos.gov.v1beta1.QueryDepositsResponse"<\x82\xd3\xe4\x93\x026\x124/cosmos/gov/v1beta1/proposals/{proposal_id}/deposits\x12\xa3\x01\n\x0bTallyResult\x12+.cosmos.gov.v1beta1.QueryTallyResultRequest\x1a,.cosmos.gov.v1beta1.QueryTallyResultResponse"9\x82\xd3\xe4\x93\x023\x121/cosmos/gov/v1beta1/proposals/{proposal_id}/tallyB*Z(github.com/cosmos/cosmos-sdk/x/gov/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/x/gov/types'
    _QUERYPROPOSALRESPONSE.fields_by_name['proposal']._options = None
    _QUERYPROPOSALRESPONSE.fields_by_name['proposal']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPROPOSALSREQUEST._options = None
    _QUERYPROPOSALSREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYPROPOSALSRESPONSE.fields_by_name['proposals']._options = None
    _QUERYPROPOSALSRESPONSE.fields_by_name['proposals']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYVOTEREQUEST._options = None
    _QUERYVOTEREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYVOTERESPONSE.fields_by_name['vote']._options = None
    _QUERYVOTERESPONSE.fields_by_name['vote']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYVOTESRESPONSE.fields_by_name['votes']._options = None
    _QUERYVOTESRESPONSE.fields_by_name['votes']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPARAMSRESPONSE.fields_by_name['voting_params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['voting_params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPARAMSRESPONSE.fields_by_name['deposit_params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['deposit_params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPARAMSRESPONSE.fields_by_name['tally_params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['tally_params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDEPOSITREQUEST._options = None
    _QUERYDEPOSITREQUEST._serialized_options = b'\x88\xa0\x1f\x00\xe8\xa0\x1f\x00'
    _QUERYDEPOSITRESPONSE.fields_by_name['deposit']._options = None
    _QUERYDEPOSITRESPONSE.fields_by_name['deposit']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDEPOSITSRESPONSE.fields_by_name['deposits']._options = None
    _QUERYDEPOSITSRESPONSE.fields_by_name['deposits']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYTALLYRESULTRESPONSE.fields_by_name['tally']._options = None
    _QUERYTALLYRESULTRESPONSE.fields_by_name['tally']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERY.methods_by_name['Proposal']._options = None
    _QUERY.methods_by_name['Proposal']._serialized_options = b'\x82\xd3\xe4\x93\x02-\x12+/cosmos/gov/v1beta1/proposals/{proposal_id}'
    _QUERY.methods_by_name['Proposals']._options = None
    _QUERY.methods_by_name['Proposals']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/gov/v1beta1/proposals'
    _QUERY.methods_by_name['Vote']._options = None
    _QUERY.methods_by_name['Vote']._serialized_options = b'\x82\xd3\xe4\x93\x02;\x129/cosmos/gov/v1beta1/proposals/{proposal_id}/votes/{voter}'
    _QUERY.methods_by_name['Votes']._options = None
    _QUERY.methods_by_name['Votes']._serialized_options = b'\x82\xd3\xe4\x93\x023\x121/cosmos/gov/v1beta1/proposals/{proposal_id}/votes'
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\x82\xd3\xe4\x93\x02*\x12(/cosmos/gov/v1beta1/params/{params_type}'
    _QUERY.methods_by_name['Deposit']._options = None
    _QUERY.methods_by_name['Deposit']._serialized_options = b'\x82\xd3\xe4\x93\x02B\x12@/cosmos/gov/v1beta1/proposals/{proposal_id}/deposits/{depositor}'
    _QUERY.methods_by_name['Deposits']._options = None
    _QUERY.methods_by_name['Deposits']._serialized_options = b'\x82\xd3\xe4\x93\x026\x124/cosmos/gov/v1beta1/proposals/{proposal_id}/deposits'
    _QUERY.methods_by_name['TallyResult']._options = None
    _QUERY.methods_by_name['TallyResult']._serialized_options = b'\x82\xd3\xe4\x93\x023\x121/cosmos/gov/v1beta1/proposals/{proposal_id}/tally'
    _QUERYPROPOSALREQUEST._serialized_start = 180
    _QUERYPROPOSALREQUEST._serialized_end = 223
    _QUERYPROPOSALRESPONSE._serialized_start = 225
    _QUERYPROPOSALRESPONSE._serialized_end = 302
    _QUERYPROPOSALSREQUEST._serialized_start = 305
    _QUERYPROPOSALSREQUEST._serialized_end = 493
    _QUERYPROPOSALSRESPONSE._serialized_start = 496
    _QUERYPROPOSALSRESPONSE._serialized_end = 636
    _QUERYVOTEREQUEST._serialized_start = 638
    _QUERYVOTEREQUEST._serialized_end = 702
    _QUERYVOTERESPONSE._serialized_start = 704
    _QUERYVOTERESPONSE._serialized_end = 769
    _QUERYVOTESREQUEST._serialized_start = 771
    _QUERYVOTESREQUEST._serialized_end = 871
    _QUERYVOTESRESPONSE._serialized_start = 874
    _QUERYVOTESRESPONSE._serialized_end = 1002
    _QUERYPARAMSREQUEST._serialized_start = 1004
    _QUERYPARAMSREQUEST._serialized_end = 1045
    _QUERYPARAMSRESPONSE._serialized_start = 1048
    _QUERYPARAMSRESPONSE._serialized_end = 1258
    _QUERYDEPOSITREQUEST._serialized_start = 1260
    _QUERYDEPOSITREQUEST._serialized_end = 1331
    _QUERYDEPOSITRESPONSE._serialized_start = 1333
    _QUERYDEPOSITRESPONSE._serialized_end = 1407
    _QUERYDEPOSITSREQUEST._serialized_start = 1409
    _QUERYDEPOSITSREQUEST._serialized_end = 1512
    _QUERYDEPOSITSRESPONSE._serialized_start = 1515
    _QUERYDEPOSITSRESPONSE._serialized_end = 1652
    _QUERYTALLYRESULTREQUEST._serialized_start = 1654
    _QUERYTALLYRESULTREQUEST._serialized_end = 1700
    _QUERYTALLYRESULTRESPONSE._serialized_start = 1702
    _QUERYTALLYRESULTRESPONSE._serialized_end = 1782
    _QUERY._serialized_start = 1785
    _QUERY._serialized_end = 3021




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgCreateVestingAccount(_message.Message):
    __slots__ = ['amount', 'delayed', 'end_time', 'from_address', 'to_address']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DELAYED_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    FROM_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TO_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    delayed: bool
    end_time: int
    from_address: str
    to_address: str

    def __init__(self, from_address: _Optional[str]=..., to_address: _Optional[str]=..., amount: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., end_time: _Optional[int]=..., delayed: bool=...) -> None:
        ...

class MsgCreateVestingAccountResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...
